==> RSTouchscreenNG-1.4.17.zip: RSTouchscreenNG/projects/pages/src/lib/console.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, ViewChild, ElementRef, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, RepetierState, QuickCommandConfig, ServerState} from "binding";
import {RSGCodeKeyboard, RSSelect, RSStringKeyboard} from "front-ui";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-printer-commands",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <rs-sideicon *ngIf="!active?.printing && (server$|async).features['touch-move']" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
        <rs-empty-sideicon *ngIf="!active?.printing && !(server$|async).features['touch-move']"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *ngIf="active?.printing && (server$|async).features['touch-status']" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *rsIfConnected="false"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-printer-commands"></i> <?php _('Console') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1 log-container">
          <div class="regular-grid margin-leftright">
            <div class="col-2 margin-bottom">
              <rs-button class="secondary full" style="margin:auto;white-space: nowrap;overflow: hidden" (hit)="selectGCode()">
                <h3><?php _('Send G-Code') ?></h3></rs-button>
            </div>
            <div class="col-2 margin-bottom" *ngIf="printer?.config?.quickCommands?.length>0 && (server$|async).features['show-quick-commands']">
              <rs-button class="secondary full" style="margin:auto;white-space: nowrap;overflow: hidden" (hit)="selectCommand()">
                <h3><?php _('Send Predefined') ?><span class="caret"></span></h3></rs-button>
            </div>
          </div>
          <div class="regular-grid margin-leftright">
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleCommands($event)" [checked]="printer.log.logCommands" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('CMDs') ?></div>
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleACK($event)" [checked]="printer.log.logACK" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('ACK') ?></div>
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="togglePause($event)" [checked]="printer.log.paused" style="margin:auto;twhite-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('Pause') ?></div>
            <div class="col-4 margin-bottom hide-max-480" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleM105(!$event)" [checked]="!printer.log.logM105" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('Filter M105') ?></div>
          </div>
          <div class="log" #log rsDrag>
          </div>
        </div>
      </main>
    </rs-page>`
})
export class ConsoleComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  @ViewChild("log") logElement: ElementRef;
  lastLogId = -1;
  logUpdatePlanned: any = false;

  private printersSubscription: SubscriptionLike;

  constructor(private printerAction: PrinterAction,
              private stringKbd: RSStringKeyboard,
              public rsselect: RSSelect,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.server$ = store.select("server");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
        if (this.logUpdatePlanned === false && this.printer.log.lastLogStart !== this.lastLogId && this.logElement) {
          this.logUpdatePlanned = setTimeout(() => {
            this.updateLogView();
          }, 500);
          this.lastLogId = this.printer.log.lastLogStart;
          const elem = this.logElement.nativeElement;
          elem.innerHTML = this.printer.log.history.join("");
          if (elem) {
            elem.scrollTop = elem.scrollHeight;
          }
        }
      } else {
        this.printer = undefined;
      }
    });
  }

  updateLogView(): void {
    this.lastLogId = this.printer.log.lastLogStart;
    const elem = this.logElement.nativeElement;
    elem.innerHTML = this.printer.log.history.join("");
    if (elem) {
      elem.scrollTop = elem.scrollHeight;
    }
    this.logUpdatePlanned = false;
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    if (this.logUpdatePlanned !== false) {
      clearTimeout(this.logUpdatePlanned);
    }
  }

  // send gcode directly
  selectGCode(): void {
    this.stringKbd.getString("", "<?php _('G-Code to Send') ?>", {preferUppercase: true}).then((cmd) => {
      this.printerAction.sendGCode(this.printer.slug, cmd);
    }, () => {
    });
  }

  // select predefined command
  async selectCommand() {
    await this.printerAction.updateVisibleQuickCommands(this.printer.slug)
    this.rsselect.select(this.printer.config.quickCommands.filter((quick) => this.printer.visibleQuickCommands[quick.name] && !(!quick.visibleWhenPrinting && this.printer.printing)), "name", "<?php _('Select Command') ?>").then((data:QuickCommandConfig) => {
      this.printerAction.sendQuickCommand(this.printer.slug, data.name);
    }, () => {
    });
  }

  toggleCommands(v: boolean): void {
    this.printerAction.setLogCommands(this.printer.slug, v);
  }

  toggleACK(v: boolean): void {
    this.printerAction.setLogACK(this.printer.slug, v);
  }

  togglePause(v: boolean): void {
    this.printerAction.setLogPause(this.printer.slug, v);
  }

  toggleM105(v: boolean): void {
    this.printerAction.setLogM105(this.printer.slug, v);
  }

}

==> RSTouchscreenNG-1.4.18.zip: RSTouchscreenNG/projects/pages/src/lib/console.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, ViewChild, ElementRef, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, RepetierState, QuickCommandConfig, ServerState} from "binding";
import {RSGCodeKeyboard, RSSelect, RSStringKeyboard} from "front-ui";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-printer-commands",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *rsIfPrinting="true" title="<?php _('Print') ?>" icon="rs rs-print" link="/print-status"></rs-sideicon>
        <rs-sideicon *ngIf="!active?.printing && (server$|async).features['touch-move']" icon="rs rs-move-xy" title="<?php _('Move') ?>" link="/move-tool"></rs-sideicon>
        <rs-empty-sideicon *ngIf="!active?.printing && !(server$|async).features['touch-move']"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *ngIf="active?.printing && (server$|async).features['touch-status']" icon="rs rs-params" title="<?php _('Status') ?>" link="/params"></rs-sideicon>
        <rs-empty-sideicon *ngIf="!active?.printing || !((server$|async).features['touch-status'])"></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="rs rs-printer-commands"></i> <?php _('Console') ?></rs-headline>
        <div *rsIfConnected="true" class="content-h1 log-container">
          <div class="regular-grid margin-leftright">
            <div class="col-2 margin-bottom">
              <rs-button class="secondary full" style="margin:auto;white-space: nowrap;overflow: hidden" (hit)="selectGCode()">
                <h3><?php _('Send G-Code') ?></h3></rs-button>
            </div>
            <div class="col-2 margin-bottom" *ngIf="printer?.config?.quickCommands?.length>0 && (server$|async).features['show-quick-commands']">
              <rs-button class="secondary full" style="margin:auto;white-space: nowrap;overflow: hidden" (hit)="selectCommand()">
                <h3><?php _('Send Predefined') ?><span class="caret"></span></h3></rs-button>
            </div>
          </div>
          <div class="regular-grid margin-leftright">
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleCommands($event)" [checked]="printer.log.logCommands" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('CMDs') ?></div>
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleACK($event)" [checked]="printer.log.logACK" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('ACK') ?></div>
            <div class="col-4 margin-bottom" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="togglePause($event)" [checked]="printer.log.paused" style="margin:auto;twhite-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('Pause') ?></div>
            <div class="col-4 margin-bottom hide-max-480" style="margin:auto;white-space: nowrap;overflow: hidden">
              <rs-switch (checkedChange)="toggleM105(!$event)" [checked]="!printer.log.logM105" style="margin:auto;white-space: nowrap;overflow: hidden"></rs-switch>
              <?php _('Filter M105') ?></div>
          </div>
          <div class="log" #log rsDrag>
          </div>
        </div>
      </main>
    </rs-page>`
})
export class ConsoleComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  server$: Observable<ServerState>;
  @ViewChild("log") logElement: ElementRef;
  lastLogId = -1;
  logUpdatePlanned: any = false;

  private printersSubscription: SubscriptionLike;

  constructor(private printerAction: PrinterAction,
              private stringKbd: RSStringKeyboard,
              public rsselect: RSSelect,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.server$ = store.select("server");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
        if (this.logUpdatePlanned === false && this.printer.log.lastLogStart !== this.lastLogId && this.logElement) {
          this.logUpdatePlanned = setTimeout(() => {
            this.updateLogView();
          }, 500);
          this.lastLogId = this.printer.log.lastLogStart;
          const elem = this.logElement.nativeElement;
          elem.innerHTML = this.printer.log.history.join("");
          if (elem) {
            elem.scrollTop = elem.scrollHeight;
          }
        }
      } else {
        this.printer = undefined;
      }
    });
  }

  updateLogView(): void {
    this.lastLogId = this.printer.log.lastLogStart;
    const elem = this.logElement.nativeElement;
    elem.innerHTML = this.printer.log.history.join("");
    if (elem) {
      elem.scrollTop = elem.scrollHeight;
    }
    this.logUpdatePlanned = false;
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    if (this.logUpdatePlanned !== false) {
      clearTimeout(this.logUpdatePlanned);
    }
  }

  // send gcode directly
  selectGCode(): void {
    this.stringKbd.getString("", "<?php _('G-Code to Send') ?>", {preferUppercase: true}).then((cmd) => {
      this.printerAction.sendGCode(this.printer.slug, cmd);
    }, () => {
    });
  }

  // select predefined command
  async selectCommand() {
    await this.printerAction.updateVisibleQuickCommands(this.printer.slug)
    this.rsselect.select(this.printer.config.quickCommands.filter((quick) => this.printer.visibleQuickCommands[quick.name] && !(!quick.visibleWhenPrinting && this.printer.printing)), "name", "<?php _('Select Command') ?>").then((data:QuickCommandConfig) => {
      this.printerAction.sendQuickCommand(this.printer.slug, data.name);
    }, () => {
    });
  }

  toggleCommands(v: boolean): void {
    this.printerAction.setLogCommands(this.printer.slug, v);
  }

  toggleACK(v: boolean): void {
    this.printerAction.setLogACK(this.printer.slug, v);
  }

  togglePause(v: boolean): void {
    this.printerAction.setLogPause(this.printer.slug, v);
  }

  toggleM105(v: boolean): void {
    this.printerAction.setLogM105(this.printer.slug, v);
  }

}
